bayespy.inference.vmp.nodes.gaussian.GaussianGammaMoments.compute_fixed_moments
===============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaMoments.compute_fixed_moments